# Change Log

## v0.4.3 (2016-10-24)

**BugFix**

- fix run tomacco_cli
- fix force tomacco

## v0.4.2 (2016-08-01)

**Features**

- add cli script for shortcut

## v0.3.2 (2016-06-28)

**BugFix**

- fix import error


## v0.3.1 (2016-06-26)

**Features:**

- run commands with start and stop tomacco
